==> grib2io-0.9.1.tar.gz: grib2io-0.9.1/grib2io/tables/section4_discipline2.py <==
table_4_2_2_0  = {
'0':['Land Cover (0=sea, 1=land)','Proportion','LAND'],
'1':['Surface Roughness','m','SFCR'],
'2':['Soil Temperature ***','K','TSOIL'],
'3':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
'4':['Vegetation','%','VEG'],
'5':['Water Runoff','kg m-2','WATR'],
'6':['Evapotranspiration','kg-2 s-1','EVAPT'],
'7':['Model Terrain Height','m','MTERH'],
'8':['Land Use','See Table 4.212','LANDU'],
'9':['Volumetric Soil Moisture Content **','Proportion','SOILW'],
'10':['Ground Heat Flux *','W m-2','GFLUX'],
'11':['Moisture Availability','%','MSTAV'],
'12':['Exchange Coefficient','kg m-2 s-1','SFEXC'],
'13':['Plant Canopy Surface Water','kg m-2','CNWAT'],
'14':['Blackadars Mixing Length Scale','m','BMIXL'],
'15':['Canopy Conductance','m s-1','CCOND'],
'16':['Minimal Stomatal Resistance','s m-1','RSMIN'],
'17':['Wilting Point *','Proportion','WILT'],
'18':['Solar parameter in canopy conductance','Proportion','RCS'],
'19':['Temperature parameter in canopy','Proportion','RCT'],
'20':['Humidity parameter in canopy conductance','Proportion','RCQ'],
'21':['Soil moisture parameter in canopy conductance','Proportion','RCSOL'],
'22':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
'23':['Column-Integrated Soil Water ***','kg m-2','CISOILW'],
'24':['Heat Flux','W m-2','HFLUX'],
'25':['Volumetric Soil Moisture','m3 m-3','VSOILM'],
'26':['Wilting Point','kg m-3','WILT'],
'27':['Volumetric Wilting Point','m3 m-3','VWILTP'],
'28':['Leaf Area Index','Numeric','LEAINX'],
'29':['Evergreen Forest Cover','Proportion','EVGFC'],
'30':['Deciduous Forest Cover','Proportion','DECFC'],
'31':['Normalized Differential Vegetation Index (NDVI)','Numeric','NDVINX'],
'32':['Root Depth of Vegetation','m','RDVEG'],
'33':['Water Runoff and Drainage ****','kg m-2','WROD'],
'34':['Surface Water Runoff ****','kg m-2','SFCWRO'],
'35':['Tile Class','See Table 4.243','TCLASS'],
'36':['Tile Fraction','Proportion','TFRCT'],
'37':['Tile Percentage','%','TPERCT'],
'38':['Soil Volumetric Ice Content (Water Equivalent)','m3 m-3','SOILVIC'],
'39':['Evapotranspiration Rate','kg m-2 s-1','EVAPTRAT'],
'39-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Volumetric Soil Moisture Content','Fraction','SOILW'],
'193':['Ground Heat Flux','W m-2','GFLUX'],
'194':['Moisture Availability','%','MSTAV'],
'195':['Exchange Coefficient','(kg m-3) (m s-1)','SFEXC'],
'196':['Plant Canopy Surface Water','kg m-2','CNWAT'],
'197':['Blackadar’s Mixing Length Scale','m','BMIXL'],
'198':['Vegetation Type','Integer (0-13)','VGTYP'],
'199':['Canopy Conductance','m s-1','CCOND'],
'200':['Minimal Stomatal Resistance','s m-1','RSMIN'],
'201':['Wilting Point','Fraction','WILT'],
'202':['Solar parameter in canopy conductance','Fraction','RCS'],
'203':['Temperature parameter in canopy conductance','Fraction','RCT'],
'204':['Humidity parameter in canopy conductance','Fraction','RCQ'],
'205':['Soil moisture parameter in canopy conductance','Fraction','RCSOL'],
'206':['Rate of water dropping from canopy to ground','unknown','RDRIP'],
'207':['Ice-free water surface','%','ICWAT'],
'208':['Surface exchange coefficients for T and Q divided by delta z','m s-1','AKHS'],
'209':['Surface exchange coefficients for U and V divided by delta z','m s-1','AKMS'],
'210':['Vegetation canopy temperature','K','VEGT'],
'211':['Surface water storage','Kg m-2','SSTOR'],
'212':['Liquid soil moisture content (non-frozen)','Kg m-2','LSOIL'],
'213':['Open water evaporation (standing water)','W m-2','EWATR'],
'214':['Groundwater recharge','Kg m-2','GWREC'],
'215':['Flood plain recharge','Kg m-2','QREC'],
'216':['Roughness length for heat','m','SFCRH'],
'217':['Normalized Difference Vegetation Index','unknown','NDVI'],
'218':['Land-sea coverage (nearest neighbor) [land=1,sea=0]','unknown','LANDN'],
'219':['Asymptotic mixing length scale','m','AMIXL'],
'220':['Water vapor added by precip assimilation','Kg m-2','WVINC'],
'221':['Water condensate added by precip assimilation','Kg m-2','WCINC'],
'222':['Water Vapor Flux Convergance (Vertical Int)','Kg m-2','WVCONV'],
'223':['Water Condensate Flux Convergance (Vertical Int)','Kg m-2','WCCONV'],
'224':['Water Vapor Zonal Flux (Vertical Int)','Kg m-2','WVUFLX'],
'225':['Water Vapor Meridional Flux (Vertical Int)','Kg m-2','WVVFLX'],
'226':['Water Condensate Zonal Flux (Vertical Int)','Kg m-2','WCUFLX'],
'227':['Water Condensate Meridional Flux (Vertical Int)','Kg m-2','WCVFLX'],
'228':['Aerodynamic conductance','m s-1','ACOND'],
'229':['Canopy water evaporation','W m-2','EVCW'],
'230':['Transpiration','W m-2','TRANS'],
'231':['Seasonally Minimum Green Vegetation Fraction (over 1-year period)','%','VEGMIN'],
'232':['Seasonally Maximum Green Vegetation Fraction (over 1-year period)','%','VEGMAX'],
'233':['Land Fraction','Fraction','LANDFRC'],
'234':['Lake Fraction','Fraction','LAKEFRC'],
'235':['Precipitation Advected Heat Flux','W m-2','PAHFLX'],
'236':['Water Storage in Aquifer','Kg m-2','WATERSA'],
'237':['Evaporation of Intercepted Water','Kg m-2','EIWATER'],
'238':['Plant Transpiration','Kg m-2','PLANTTR'],
'239':['Soil Surface Evaporation','Kg m-2','SOILSE'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_1  = {
'0-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Cold Advisory for Newborn Livestock','unknown','CANL'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_3  = {
'0':['Soil Type','See Table 4.213','SOTYP'],
'1':['Upper Layer Soil Temperature *','K','UPLST'],
'2':['Upper Layer Soil Moisture *','kg m-3','UPLSM'],
'3':['Lower Layer Soil Moisture *','kg m-3','LOWLSM'],
'4':['Bottom Layer Soil Temperature *','K','BOTLST'],
'5':['Liquid Volumetric Soil Moisture (non-frozen)**','Proportion','SOILL'],
'6':['Number of Soil Layers in Root Zone','Numeric','RLYRS'],
'7':['Transpiration Stress-onset (soil moisture)**','Proportion','SMREF'],
'8':['Direct Evaporation Cease (soil moisture)**','Proportion','SMDRY'],
'9':['Soil Porosity**','Proportion','POROS'],
'10':['Liquid Volumetric Soil Moisture (Non-Frozen)','m3 m-3','LIQVSM'],
'11':['Volumetric Transpiration Stree-Onset(Soil Moisture)','m3 m-3','VOLTSO'],
'12':['Transpiration Stree-Onset(Soil Moisture)','kg m-3','TRANSO'],
'13':['Volumetric Direct Evaporation Cease(Soil Moisture)','m3 m-3','VOLDEC'],
'14':['Direct Evaporation Cease(Soil Moisture)','kg m-3','DIREC'],
'15':['Soil Porosity','m3 m-3','SOILP'],
'16':['Volumetric Saturation Of Soil Moisture','m3 m-3','VSOSM'],
'17':['Saturation Of Soil Moisture','kg m-3','SATOSM'],
'18':['Soil Temperature','K','SOILTMP'],
'19':['Soil Moisture','kg m-3','SOILMOI'],
'20':['Column-Integrated Soil Moisture','kg m-2','CISOILM'],
'21':['Soil Ice','kg m-3','SOILICE'],
'22':['Column-Integrated Soil Ice','kg m-2','CISICE'],
'23':['Liquid Water in Snow Pack','kg m-2','LWSNWP'],
'24':['Frost Index','kg day-1','FRSTINX'],
'25':['Snow Depth at Elevation Bands','kg m-2','SNWDEB'],
'26':['Soil Heat Flux','W m-2','SHFLX'],
'27':['Soil Depth','m','SOILDEP'],
'28-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Liquid Volumetric Soil Moisture (non Frozen)','Proportion','SOILL'],
'193':['Number of Soil Layers in Root Zone','non-dim','RLYRS'],
'194':['Surface Slope Type','Index','SLTYP'],
'195':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
'196':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
'197':['Soil Porosity','Proportion','POROS'],
'198':['Direct Evaporation from Bare Soil','W m-2','EVBS'],
'199':['Land Surface Precipitation Accumulation','kg m-2','LSPA'],
'200':['Bare Soil Surface Skin temperature','K','BARET'],
'201':['Average Surface Skin Temperature','K','AVSFT'],
'202':['Effective Radiative Skin Temperature','K','RADT'],
'203':['Field Capacity','Fraction','FLDCP'],
'204':['Soil Moisture Availability In The Top Soil Layer','%','MSTAV'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_4  = {
'0':['Fire Outlook','See Table 4.224','FIREOLK'],
'1':['Fire Outlook Due to Dry Thunderstorm','See Table 4.224','FIREODT'],
'2':['Haines Index','Numeric','HINDEX'],
'3':['Fire Burned Area','%','FBAREA'],
'4':['Fosberg Index *','Numeric','FOSINDX'],
'5':['Fire Weath Index (Canadian Forest Service)','Numeric','FWINX'],
'6':['Fine Fuel Moisture Code (Canadian Forest Service)','Numeric','FFMCODE'],
'7':['Duff Moisture Code (Canadian Forest Service)','Numeric','DUFMCODE'],
'8':['Drought Code (Canadian Forest Service)','Numeric','DRTCODE'],
'9':['Initial Fire Spread Index (Canadian Forest Service)','Numeric','INFSINX'],
'10':['Fire Build Up Index (Canadian Forest Service)','Numeric','FBUPINX'],
'11':['Fire Daily Severity Rating (Canadian Forest Service)','Numeric','FDSRTE'],
'12-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_5  = {
'1':['Glacier Temperature','K','GLACTMP'],
'2-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}

==> grib2io-1.0.3.tar.gz: grib2io-1.0.3/grib2io/tables/section4_discipline2.py <==
table_4_2_2_0  = {
'0':['Land Cover (0=sea, 1=land)','Proportion','LAND'],
'1':['Surface Roughness','m','SFCR'],
'2':['Soil Temperature','K','TSOIL'],
'3':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
'4':['Vegetation','%','VEG'],
'5':['Water Runoff','kg m-2','WATR'],
'6':['Evapotranspiration','kg-2 s-1','EVAPT'],
'7':['Model Terrain Height','m','MTERH'],
'8':['Land Use','See Table 4.212','LANDU'],
'9':['Volumetric Soil Moisture Content','Proportion','SOILW'],
'10':['Ground Heat Flux','W m-2','GFLUX'],
'11':['Moisture Availability','%','MSTAV'],
'12':['Exchange Coefficient','kg m-2 s-1','SFEXC'],
'13':['Plant Canopy Surface Water','kg m-2','CNWAT'],
'14':['Blackadars Mixing Length Scale','m','BMIXL'],
'15':['Canopy Conductance','m s-1','CCOND'],
'16':['Minimal Stomatal Resistance','s m-1','RSMIN'],
'17':['Wilting Point','Proportion','WILT'],
'18':['Solar parameter in canopy conductance','Proportion','RCS'],
'19':['Temperature parameter in canopy','Proportion','RCT'],
'20':['Humidity parameter in canopy conductance','Proportion','RCQ'],
'21':['Soil moisture parameter in canopy conductance','Proportion','RCSOL'],
'22':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
'23':['Column-Integrated Soil Water','kg m-2','CISOILW'],
'24':['Heat Flux','W m-2','HFLUX'],
'25':['Volumetric Soil Moisture','m3 m-3','VSOILM'],
'26':['Wilting Point','kg m-3','WILT'],
'27':['Volumetric Wilting Point','m3 m-3','VWILTP'],
'28':['Leaf Area Index','Numeric','LEAINX'],
'29':['Evergreen Forest Cover','Proportion','EVGFC'],
'30':['Deciduous Forest Cover','Proportion','DECFC'],
'31':['Normalized Differential Vegetation Index (NDVI)','Numeric','NDVINX'],
'32':['Root Depth of Vegetation','m','RDVEG'],
'33':['Water Runoff and Drainage','kg m-2','WROD'],
'34':['Surface Water Runoff','kg m-2','SFCWRO'],
'35':['Tile Class','See Table 4.243','TCLASS'],
'36':['Tile Fraction','Proportion','TFRCT'],
'37':['Tile Percentage','%','TPERCT'],
'38':['Soil Volumetric Ice Content (Water Equivalent)','m3 m-3','SOILVIC'],
'39':['Evapotranspiration Rate','kg m-2 s-1','EVAPTRAT'],
'40':['Potential Evapotranspiration Rate','kg m-2 s-1','PERATE'],
'41':['Snow Melt Rate','kg m-2 s-1','SMRATE'],
'42':['Water Runoff and Drainage Rate','kg m-2 s-1','WRDRATE'],
'43':['Drainage direction','See Table 4.250','DRAINDIR'],
'44':['Upstream Area','m2','UPSAREA'],
'45-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Volumetric Soil Moisture Content','Fraction','SOILW'],
'193':['Ground Heat Flux','W m-2','GFLUX'],
'194':['Moisture Availability','%','MSTAV'],
'195':['Exchange Coefficient','(kg m-3) (m s-1)','SFEXC'],
'196':['Plant Canopy Surface Water','kg m-2','CNWAT'],
'197':['Blackadar’s Mixing Length Scale','m','BMIXL'],
'198':['Vegetation Type','Integer (0-13)','VGTYP'],
'199':['Canopy Conductance','m s-1','CCOND'],
'200':['Minimal Stomatal Resistance','s m-1','RSMIN'],
'201':['Wilting Point','Fraction','WILT'],
'202':['Solar parameter in canopy conductance','Fraction','RCS'],
'203':['Temperature parameter in canopy conductance','Fraction','RCT'],
'204':['Humidity parameter in canopy conductance','Fraction','RCQ'],
'205':['Soil moisture parameter in canopy conductance','Fraction','RCSOL'],
'206':['Rate of water dropping from canopy to ground','unknown','RDRIP'],
'207':['Ice-free water surface','%','ICWAT'],
'208':['Surface exchange coefficients for T and Q divided by delta z','m s-1','AKHS'],
'209':['Surface exchange coefficients for U and V divided by delta z','m s-1','AKMS'],
'210':['Vegetation canopy temperature','K','VEGT'],
'211':['Surface water storage','Kg m-2','SSTOR'],
'212':['Liquid soil moisture content (non-frozen)','Kg m-2','LSOIL'],
'213':['Open water evaporation (standing water)','W m-2','EWATR'],
'214':['Groundwater recharge','Kg m-2','GWREC'],
'215':['Flood plain recharge','Kg m-2','QREC'],
'216':['Roughness length for heat','m','SFCRH'],
'217':['Normalized Difference Vegetation Index','unknown','NDVI'],
'218':['Land-sea coverage (nearest neighbor) [land=1,sea=0]','unknown','LANDN'],
'219':['Asymptotic mixing length scale','m','AMIXL'],
'220':['Water vapor added by precip assimilation','Kg m-2','WVINC'],
'221':['Water condensate added by precip assimilation','Kg m-2','WCINC'],
'222':['Water Vapor Flux Convergance (Vertical Int)','Kg m-2','WVCONV'],
'223':['Water Condensate Flux Convergance (Vertical Int)','Kg m-2','WCCONV'],
'224':['Water Vapor Zonal Flux (Vertical Int)','Kg m-2','WVUFLX'],
'225':['Water Vapor Meridional Flux (Vertical Int)','Kg m-2','WVVFLX'],
'226':['Water Condensate Zonal Flux (Vertical Int)','Kg m-2','WCUFLX'],
'227':['Water Condensate Meridional Flux (Vertical Int)','Kg m-2','WCVFLX'],
'228':['Aerodynamic conductance','m s-1','ACOND'],
'229':['Canopy water evaporation','W m-2','EVCW'],
'230':['Transpiration','W m-2','TRANS'],
'231':['Seasonally Minimum Green Vegetation Fraction (over 1-year period)','%','VEGMIN'],
'232':['Seasonally Maximum Green Vegetation Fraction (over 1-year period)','%','VEGMAX'],
'233':['Land Fraction','Fraction','LANDFRC'],
'234':['Lake Fraction','Fraction','LAKEFRC'],
'235':['Precipitation Advected Heat Flux','W m-2','PAHFLX'],
'236':['Water Storage in Aquifer','Kg m-2','WATERSA'],
'237':['Evaporation of Intercepted Water','Kg m-2','EIWATER'],
'238':['Plant Transpiration','Kg m-2','PLANTTR'],
'239':['Soil Surface Evaporation','Kg m-2','SOILSE'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_1  = {
'0-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Cold Advisory for Newborn Livestock','unknown','CANL'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_3  = {
'0':['Soil Type','See Table 4.213','SOTYP'],
'1':['Upper Layer Soil Temperature','K','UPLST'],
'2':['Upper Layer Soil Moisture','kg m-3','UPLSM'],
'3':['Lower Layer Soil Moisture','kg m-3','LOWLSM'],
'4':['Bottom Layer Soil Temperature','K','BOTLST'],
'5':['Liquid Volumetric Soil Moisture (non-frozen)','Proportion','SOILL'],
'6':['Number of Soil Layers in Root Zone','Numeric','RLYRS'],
'7':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
'8':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
'9':['Soil Porosity','Proportion','POROS'],
'10':['Liquid Volumetric Soil Moisture (Non-Frozen)','m3 m-3','LIQVSM'],
'11':['Volumetric Transpiration Stree-Onset(Soil Moisture)','m3 m-3','VOLTSO'],
'12':['Transpiration Stree-Onset(Soil Moisture)','kg m-3','TRANSO'],
'13':['Volumetric Direct Evaporation Cease(Soil Moisture)','m3 m-3','VOLDEC'],
'14':['Direct Evaporation Cease(Soil Moisture)','kg m-3','DIREC'],
'15':['Soil Porosity','m3 m-3','SOILP'],
'16':['Volumetric Saturation Of Soil Moisture','m3 m-3','VSOSM'],
'17':['Saturation Of Soil Moisture','kg m-3','SATOSM'],
'18':['Soil Temperature','K','SOILTMP'],
'19':['Soil Moisture','kg m-3','SOILMOI'],
'20':['Column-Integrated Soil Moisture','kg m-2','CISOILM'],
'21':['Soil Ice','kg m-3','SOILICE'],
'22':['Column-Integrated Soil Ice','kg m-2','CISICE'],
'23':['Liquid Water in Snow Pack','kg m-2','LWSNWP'],
'24':['Frost Index','kg day-1','FRSTINX'],
'25':['Snow Depth at Elevation Bands','kg m-2','SNWDEB'],
'26':['Soil Heat Flux','W m-2','SHFLX'],
'27':['Soil Depth','m','SOILDEP'],
'28':['Snow Temperature','K','SNOWTMP'],
'29':['Ice Temperature','K','ICETEMP'],
'30-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Liquid Volumetric Soil Moisture (non Frozen)','Proportion','SOILL'],
'193':['Number of Soil Layers in Root Zone','non-dim','RLYRS'],
'194':['Surface Slope Type','Index','SLTYP'],
'195':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
'196':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
'197':['Soil Porosity','Proportion','POROS'],
'198':['Direct Evaporation from Bare Soil','W m-2','EVBS'],
'199':['Land Surface Precipitation Accumulation','kg m-2','LSPA'],
'200':['Bare Soil Surface Skin temperature','K','BARET'],
'201':['Average Surface Skin Temperature','K','AVSFT'],
'202':['Effective Radiative Skin Temperature','K','RADT'],
'203':['Field Capacity','Fraction','FLDCP'],
'204':['Soil Moisture Availability In The Top Soil Layer','%','MSTAV'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_4  = {
'0':['Fire Outlook','See Table 4.224','FIREOLK'],
'1':['Fire Outlook Due to Dry Thunderstorm','See Table 4.224','FIREODT'],
'2':['Haines Index','Numeric','HINDEX'],
'3':['Fire Burned Area','%','FBAREA'],
'4':['Fosberg Index','Numeric','FOSINDX'],
'5':['Fire Weath Index (Canadian Forest Service)','Numeric','FWINX'],
'6':['Fine Fuel Moisture Code (Canadian Forest Service)','Numeric','FFMCODE'],
'7':['Duff Moisture Code (Canadian Forest Service)','Numeric','DUFMCODE'],
'8':['Drought Code (Canadian Forest Service)','Numeric','DRTCODE'],
'9':['Initial Fire Spread Index (Canadian Forest Service)','Numeric','INFSINX'],
'10':['Fire Build Up Index (Canadian Forest Service)','Numeric','FBUPINX'],
'11':['Fire Daily Severity Rating (Canadian Forest Service)','Numeric','FDSRTE'],
'12':['Keetch-Byram Drought Index','Numeric','KRIDX'],
'13':['Drought Factor (as defined by the Australian forest service)','Numeric','DRFACT'],
'14':['Rate of Spread (as defined by the Australian forest service)','m s-1','RATESPRD'],
'15':['Fire Danger index (as defined by the Australian forest service)','Numeric','FIREDIDX'],
'16':['Drought Factor (as defined by the Australian forest service)','Numeric','DRFACT'],
'17':['Spread component (as defined by the Australian forest service)','Numeric','SPRDCOMP'],
'18':['Ignition Component (as defined by the Australian forest service)','%','IGNCOMP'],
'19':['Energy Release Component (as defined by the Australian forest service)','J m-2','ENRELCOM'],
'20-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_2_5  = {
'0':['Glacier Cover (see Note)','Proportion','GLACCOV'],
'1':['Glacier Temperature','K','GLACTMP'],
'2-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
